%global debug_package %{nil}
%global pypi_name qtile
%global pypi_version 0.32.0
%global toolchain clang

Name:           %{pypi_name}
Version:        %{pypi_version}
Release:        %autorelease
Summary:        A pure-Python tiling window manager

License:        MIT AND GPL-3.0-or-later
URL:            https://qtile.org/
Source0:        %{pypi_source}

BuildRequires:  clang
BuildRequires:  desktop-file-utils
BuildRequires:  pkgconfig(python3)
BuildRequires:  pkgconfig(x11)
BuildRequires:  python3dist(cairocffi)
BuildRequires:  python3dist(cairocffi[xcb])
BuildRequires:  python3dist(cffi)
BuildRequires:  python3dist(dbus-fast)
BuildRequires:  python3dist(pip)
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(setuptools-scm)
BuildRequires:  python3dist(wheel)
BuildRequires:  python3dist(xcffib)
Recommends:     python3dist(dbus-fast)
Recommends:     python3dist(imaplib2)
Recommends:     python3dist(keyring)
Recommends:     python3dist(mailbox)
Recommends:     python3dist(psutil)
Recommends:     python3dist(pulsectl)
Recommends:     python3dist(pulsectl-asyncio)
Recommends:     python3dist(python-mpd2)
Recommends:     python3dist(pytz)
Recommends:     python3dist(xdg-base-dirs)
Recommends:     python3dist(xmltodict)
Requires:       python3-libqtile = %{pypi_version}-%{release}

%global _description %{expand:
A full-featured, hackable tiling window manager written and configured in
Python.

Features:
* Simple, small and extensible. It's easy to write your own layouts, widgets
and commands.
* Configured in Python.
* Runs as an X11 WM or a Wayland compositor.
* Command shell that allows all aspects of Qtile to be managed and inspected.
* Complete remote scriptability - write scripts to set up workspaces,
manipulate windows, update status bar widgets and more.
* Qtile's remote scriptability makes it one of the most thoroughly unit-tested
window managers around.}

%description %_description

%package -n     python3-libqtile
Summary:        Qtile's Python library

%description -n python3-libqtile %_description

%package        wayland
Summary:        Qtile Wayland session
BuildRequires:  pkgconfig(wlroots)
BuildRequires:  pkgconfig(xwayland)
BuildRequires:  python3dist(pywayland)
BuildRequires:  python3dist(pywlroots)
BuildRequires:  python3dist(xkbcommon)
Requires:       python3-libqtile+wayland = %{pypi_version}-%{release}
Requires:       qtile = %{pypi_version}-%{release}

%description    wayland %_description


%pyproject_extras_subpkg -n python3-libqtile wayland


%prep
%autosetup -p1 -n %{pypi_name}-%{pypi_version}
# Remove bundled egg-info
rm -rf %{pypi_name}.egg-info
# Remove the specific license-files line
sed -i '/^license-files = \[ "LICENSE" \]$/d' pyproject.toml
# Replace the MIT license with file-based syntax
sed -i 's/license = "MIT"/license = {file = "LICENSE"}/' pyproject.toml
# Replace sudo group with wheel
sed -i 's/sudo/wheel/g' resources/99-%{pypi_name}.rules


%generate_buildrequires
%pyproject_buildrequires -x wayland


%build
%pyproject_wheel


%install
%pyproject_install
%pyproject_save_files -l libqtile

mkdir -p %{buildroot}%{_datadir}/xsessions/
desktop-file-install \
  --dir %{buildroot}%{_datadir}/xsessions/ \
  resources/%{pypi_name}.desktop

mkdir -p %{buildroot}%{_datadir}/wayland-sessions/
desktop-file-install \
  --dir %{buildroot}%{_datadir}/wayland-sessions/ \
  resources/%{pypi_name}-wayland.desktop

mkdir -p %{buildroot}%{_sysconfdir}/udev/rules.d/
install -m 644 \
  resources/99-%{pypi_name}.rules %{buildroot}%{_sysconfdir}/udev/rules.d/


%files
%doc CHANGELOG README.rst
%{_bindir}/%{pypi_name}
%{_datadir}/xsessions/%{pypi_name}.desktop
%{_sysconfdir}/udev/rules.d/99-%{pypi_name}.rules


%files -n python3-libqtile -f %{pyproject_files}


%files wayland
%{_datadir}/wayland-sessions/%{pypi_name}-wayland.desktop


%changelog
* Fri Jul 04 2025 David Andres Ramirez Salomon <david35mm@disroot.org> - 0.32.0-1
- Updated to v0.32.0
- Fixed udev rules

* Fri Apr 04 2025 David Andres Ramirez Salomon <david35mm@disroot.org> - 0.31.0-1
- Initial package
- Followed new Fedora python packaging guidelines
